@@ -2,7 +2,7 @@
 #
 # The MIT License (MIT)
 #
-# Copyright (c) Tavendo GmbH
+# Copyright (c) Crossbar.io Technologies GmbH
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -69,14 +69,14 @@ class PrefixProtocol(asyncio.Protocol):
         self.log.debug('RawSocker Asyncio: Connection made with peer {peer}', peer=self.peer)
         self._buffer = b''
         self._header = None
-        self._wait_closed = asyncio.Future()
+        self._wait_closed = txaio.create_future()
 
     @property
     def is_closed(self):
         if hasattr(self, '_wait_closed'):
             return self._wait_closed
         else:
-            f = asyncio.Future()
+            f = txaio.create_future()
             f.set_result(True)
             return f
 
@@ -205,6 +205,7 @@ class RawSocketProtocol(PrefixProtocol):
                 if data:
                     PrefixProtocol.data_received(self, data)
 
+
 ERR_SERIALIZER_UNSUPPORTED = 1
 
 ERRMAP = {
