@@ -2,7 +2,7 @@
 #
 # The MIT License (MIT)
 #
-# Copyright (c) Tavendo GmbH
+# Copyright (c) Crossbar.io Technologies GmbH
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -168,15 +168,11 @@ class ApplicationRunner(object):
                 cfg = ComponentConfig(self.realm, self.extra)
                 try:
                     session = make(cfg)
-                except Exception as e:
-                    if start_reactor:
-                        # the app component could not be created .. fatal
-                        self.log.error("{err}", err=e)
+                except Exception:
+                    self.log.failure('ApplicationSession could not be instantiated: {log_failure.value}')
+                    if start_reactor and reactor.running:
                         reactor.stop()
-                    else:
-                        # if we didn't start the reactor, it's up to the
-                        # caller to deal with errors
-                        raise
+                    raise
                 else:
                     return session
         else:
